@@ -21,38 +21,42 @@
 
 #include "src/core/lib/iomgr/resolve_address.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Returns true if addr is an IPv4-mapped IPv6 address within the
    ::ffff:0.0.0.0/96 range, or false otherwise.
 
    If addr4_out is non-NULL, the inner IPv4 address will be copied here when
    returning true. */
-int grpc_sockaddr_is_v4mapped(const grpc_resolved_address *addr,
-                              grpc_resolved_address *addr4_out);
+int grpc_sockaddr_is_v4mapped(const grpc_resolved_address* addr,
+                              grpc_resolved_address* addr4_out);
 
 /* If addr is an AF_INET address, writes the corresponding ::ffff:0.0.0.0/96
    address to addr6_out and returns true.  Otherwise returns false. */
-int grpc_sockaddr_to_v4mapped(const grpc_resolved_address *addr,
-                              grpc_resolved_address *addr6_out);
+int grpc_sockaddr_to_v4mapped(const grpc_resolved_address* addr,
+                              grpc_resolved_address* addr6_out);
 
 /* If addr is ::, 0.0.0.0, or ::ffff:0.0.0.0, writes the port number to
  *port_out (if not NULL) and returns true, otherwise returns false. */
-int grpc_sockaddr_is_wildcard(const grpc_resolved_address *addr, int *port_out);
+int grpc_sockaddr_is_wildcard(const grpc_resolved_address* addr, int* port_out);
 
 /* Writes 0.0.0.0:port and [::]:port to separate sockaddrs. */
-void grpc_sockaddr_make_wildcards(int port, grpc_resolved_address *wild4_out,
-                                  grpc_resolved_address *wild6_out);
+void grpc_sockaddr_make_wildcards(int port, grpc_resolved_address* wild4_out,
+                                  grpc_resolved_address* wild6_out);
 
 /* Writes 0.0.0.0:port. */
-void grpc_sockaddr_make_wildcard4(int port, grpc_resolved_address *wild_out);
+void grpc_sockaddr_make_wildcard4(int port, grpc_resolved_address* wild_out);
 
 /* Writes [::]:port. */
-void grpc_sockaddr_make_wildcard6(int port, grpc_resolved_address *wild_out);
+void grpc_sockaddr_make_wildcard6(int port, grpc_resolved_address* wild_out);
 
 /* Return the IP port number of a sockaddr */
-int grpc_sockaddr_get_port(const grpc_resolved_address *addr);
+int grpc_sockaddr_get_port(const grpc_resolved_address* addr);
 
 /* Set IP port number of a sockaddr */
-int grpc_sockaddr_set_port(const grpc_resolved_address *addr, int port);
+int grpc_sockaddr_set_port(const grpc_resolved_address* addr, int port);
 
 /* Converts a sockaddr into a newly-allocated human-readable string.
 
@@ -66,15 +70,19 @@ int grpc_sockaddr_set_port(const grpc_resolved_address *addr, int port);
 
    In the unlikely event of an error, returns -1 and sets *out to NULL.
    The existing value of errno is always preserved. */
-int grpc_sockaddr_to_string(char **out, const grpc_resolved_address *addr,
+int grpc_sockaddr_to_string(char** out, const grpc_resolved_address* addr,
                             int normalize);
 
 /* Returns the URI string corresponding to \a addr */
-char *grpc_sockaddr_to_uri(const grpc_resolved_address *addr);
+char* grpc_sockaddr_to_uri(const grpc_resolved_address* addr);
 
 /* Returns the URI scheme corresponding to \a addr */
-const char *grpc_sockaddr_get_uri_scheme(const grpc_resolved_address *addr);
+const char* grpc_sockaddr_get_uri_scheme(const grpc_resolved_address* addr);
 
-int grpc_sockaddr_get_family(const grpc_resolved_address *resolved_addr);
+int grpc_sockaddr_get_family(const grpc_resolved_address* resolved_addr);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* GRPC_CORE_LIB_IOMGR_SOCKADDR_UTILS_H */
